@@ -230,7 +230,14 @@ DownloadPrefs::DownloadPrefs(Profile* profile) : profile_(profile) {
         base::FilePath::StringType(1, base::FilePath::kExtensionSeparator) +
         extension);
 
-    auto_open_.insert(extension);
+    // Note that the list of file types that are not allowed to open
+    // automatically can change in the future. When the list is tightened, it is
+    // expected that some entries in the users' auto open list will get dropped
+    // permanently as a result.
+    if (FileTypePolicies::GetInstance()->IsAllowedToOpenAutomatically(
+            filename_with_extension)) {
+      auto_open_.insert(extension);
+    }
   }
 }
 
@@ -391,6 +398,10 @@ bool DownloadPrefs::IsAutoOpenEnabledBasedOnExtension(
 bool DownloadPrefs::EnableAutoOpenBasedOnExtension(
     const base::FilePath& file_name) {
   base::FilePath::StringType extension = file_name.Extension();
+  if (!FileTypePolicies::GetInstance()->IsAllowedToOpenAutomatically(
+          file_name)) {
+    return false;
+  }
 
   DCHECK(extension[0] == base::FilePath::kExtensionSeparator);
   extension.erase(0, 1);
