@@ -310,17 +310,15 @@ bool PasswordsPrivateDelegateImpl::OsReauthCall(
           : kShowPasswordAuthTokenLifetime;
   return auth_token->GetAge() <= auth_token_lifespan;
 #else
-  //modify by xiepinze, os reauth function implement, 2020/10/17, start
   //return true;
   auto ret = system("pkexec deepin-password-auth");
-  if (ret != 32512) {//该参数存在不同环境值不一样的风险，故加log跟踪，正确时不同机器不一样。
+  if (ret == 0) {
     LOG(INFO) << "true, ret = " << ret;
     return true;
     } else {
       LOG(INFO) << "false, ret = " << ret;
       return false;
     }
-  //modify by xiepinze, os reauth function implement, 2020/10/17, end
 #endif
 }
 
