@@ -435,12 +435,20 @@ export const CommandManager = Polymer({
         });
         break;
       case Command.ADD_BOOKMARK:
-        /** @type {!BookmarksEditDialogElement} */ (this.$.editDialog.get())
-            .showAddDialog(false, assert(state.selectedFolder));
+        /** @type {!BookmarksEditDialogElement} */ 
+        var bookmarkId = assert(state.selectedFolder);
+        if(Array.from(itemIds)[0]){
+          bookmarkId = Array.from(itemIds)[0];
+        }
+        (this.$.editDialog.get()).showAddDialog(false, bookmarkId);
         break;
       case Command.ADD_FOLDER:
-        /** @type {!BookmarksEditDialogElement} */ (this.$.editDialog.get())
-            .showAddDialog(true, assert(state.selectedFolder));
+        /** @type {!BookmarksEditDialogElement} */ 
+        var bookmarkId = assert(state.selectedFolder);
+        if(Array.from(itemIds)[0]){
+          bookmarkId = Array.from(itemIds)[0];
+        }
+        (this.$.editDialog.get()).showAddDialog(true, bookmarkId);
         break;
       case Command.IMPORT:
         chrome.bookmarks.import();
