@@ -63,6 +63,17 @@ bool CheckUrlAgainstWhitelist(
     return false;
   }
 
+  //@wangjun: 不检查rar后缀的文件，2021/03/09,start
+  LOG(INFO) << "CheckUrlAgainstWhitelist for: " << url.spec();
+  std::string filename_ = url.ExtractFileName();
+  if (filename_.length() > 0) {
+    std::transform(filename_.begin(), filename_.end(), filename_.begin(), ::tolower);
+    if (filename_.substr(filename_.find_last_of(".") + 1) == "rar") {
+      LOG(INFO) << "CheckUrlAgainstWhitelist NO CHECK FOR RAR FILES";
+      return true;
+    }
+  }
+  //@wangjun: 不检查rar后缀的文件，2021/03/09,end
   return (url.is_valid() && database_manager->MatchDownloadWhitelistUrl(url));
 }
 
