@@ -16,8 +16,6 @@
 #include <string>
 #include <utility>
 #include <vector>
-#include <com_deepin_daemon_mime.h>
-#include <QList>
 
 #include "base/base_paths.h"
 #include "base/command_line.h"
@@ -53,23 +51,14 @@
 #include "ui/gfx/image/image_family.h"
 #include "url/gurl.h"
 
+#include "uos/dbus_thread_manager.h"
+#include "uos/dde/dde_mime_client.h"
+
 #if defined(USE_GLIB)
 #include <glib.h>
 #endif
 
 namespace shell_integration_linux {
-//add by xiepinze, set default browser, 2020/08/26, start
-using com::deepin::daemon::Mime;
-
-const QString browserid = "org.deepin.browser.desktop";
-const QStringList mimeType = QStringList() << "x-scheme-handler/http"
-                 << "x-scheme-handler/ftp"
-                 << "x-scheme-handler/https"
-                 << "text/html"
-                 << "text/xml"
-                 << "text/xhtml_xml"
-                 << "text/xhtml+xml";
-//add by xiepinze, set default browser, 2020/08/26, end
 const char kXdgSettings[] = "xdg-settings";
 const char kXdgSettingsDefaultBrowser[] = "default-web-browser";
 const char kXdgSettingsDefaultSchemeHandler[] = "default-url-scheme-handler";
@@ -120,10 +109,10 @@ const int EXIT_XDG_SETTINGS_SYNTAX_ERROR = 1;
 // otherwise it sets Chrome as the default handler application for |protocol|.
 bool SetDefaultWebClient(const std::string& protocol) {
   //modify by xiepinze, set default browser, 2020/08/26, start
-  Mime dbusmgr("com.deepin.daemon.Mime", "/com/deepin/daemon/Mime",
-                               QDBusConnection::sessionBus(), nullptr);
-  dbusmgr.SetDefaultApp(mimeType, browserid);
-  return true;
+  // Mime dbusmgr("com.deepin.daemon.Mime", "/com/deepin/daemon/Mime",
+                              //  QDBusConnection::sessionBus(), nullptr);
+  // dbusmgr.SetDefaultApp(mimeType, browserid);
+  return dbus::uos::DBusThreadManager::Get()->GetDdeMimeClient()->SetUosDefaultBrowser();
 /*#if defined(OS_CHROMEOS)
   return true;
 #else
@@ -157,18 +146,22 @@ bool SetDefaultWebClient(const std::string& protocol) {
 // If |protocol| is empty this function checks if Chrome is the default browser,
 // otherwise it checks if Chrome is the default handler application for
 // |protocol|.
-shell_integration::DefaultWebClientState GetIsDefaultWebClient(
-    const std::string& protocol) {
-  //modify by xiepinze, set default browser, 2020/08/26, start
-  Mime dbusmgr("com.deepin.daemon.Mime", "/com/deepin/daemon/Mime",
-                               QDBusConnection::sessionBus(), nullptr);
+shell_integration::DefaultWebClientState GetIsDefaultWebClient(const std::string& protocol) {
+  // modify by wzx, set default browser, 2021/01/13, start
+  bool bIsDefault = dbus::uos::DBusThreadManager::Get()->GetDdeMimeClient()->IsUosDefaultBrowser();
+  return bIsDefault ? shell_integration::IS_DEFAULT : shell_integration::NOT_DEFAULT;
+  // modify by wzx, set default browser, 2021/01/13   end
+}
+  // modify by xiepinze, set default browser, 2020/08/26, start
+  // Mime dbusmgr("com.deepin.daemon.Mime", "/com/deepin/daemon/Mime",
+                              //  QDBusConnection::sessionBus(), nullptr);
 
-  auto reply = dbusmgr.GetDefaultApp(mimeType[0]);
-  auto defaultId = QJsonDocument::fromJson(reply.value().toStdString().c_str()).object()["Id"].toString();
-  if (defaultId == browserid)
-    return shell_integration::IS_DEFAULT;
-  else
-    return shell_integration::NOT_DEFAULT;
+  // auto reply = dbusmgr.GetDefaultApp(mimeType[0]);
+  // auto defaultId = QJsonDocument::fromJson(reply.value().toStdString().c_str()).object()["Id"].toString();
+  // if (defaultId == browserid)
+    // return shell_integration::IS_DEFAULT;
+  // else
+    // return shell_integration::NOT_DEFAULT;
 /*
 #if defined(OS_CHROMEOS)
   return shell_integration::UNKNOWN_DEFAULT;
@@ -212,7 +205,7 @@ shell_integration::DefaultWebClientState GetIsDefaultWebClient(
 #endif
 */
   //modify by xiepinze, set default browser, 2020/08/26, end
-}
+// }
 
 // https://wiki.gnome.org/Projects/GnomeShell/ApplicationBased
 // The WM_CLASS property should be set to the same as the *.desktop file without
@@ -443,15 +436,11 @@ std::string GetProgramClassClass() {
 }
 
 std::string GetIconName() {
-  //  modify by wzx, 浏览器的图标默认是如下， 2020-11-02， beigin
-// #if BUILDFLAG(GOOGLE_CHROME_BRANDING)
-  // return "google-chrome";
-// #else  // BUILDFLAG(CHROMIUM_BRANDING)
-  // return "chromium-browser";
-// #endif
-
-  return "org.deepin.browser";
-  //  modify by wzx, 浏览器的图标默认是如下， 2020-11-02， end
+#if BUILDFLAG(GOOGLE_CHROME_BRANDING)
+  return "google-chrome";
+#else  // BUILDFLAG(CHROMIUM_BRANDING)
+  return "chromium-browser";
+#endif
 }
 
 bool GetExistingShortcutContents(base::Environment* env,
@@ -478,13 +467,8 @@ bool GetExistingShortcutContents(base::Environment* env,
 base::FilePath GetWebShortcutFilename(const GURL& url) {
   // Use a prefix, because xdg-desktop-menu requires it.
 
-  //  modify by wzx, 修改产生网页快捷方式的前缀， 2020-11-02， begin
-  //std::string filename =
-  //    std::string(chrome::kBrowserProcessExecutableName) + "-" + url.spec();
-
-  std::string filename = std::string(chrome::kBrowserProcessExecutableNameUos) + "-" + url.spec();
-
-  //  modify by wzx, 修改产生网页快捷方式的前缀， 2020-11-02， end
+  std::string filename =
+     std::string(chrome::kBrowserProcessExecutableName) + "-" + url.spec();
 
   base::i18n::ReplaceIllegalCharactersInPath(&filename, '_');
 
@@ -614,10 +598,7 @@ std::string GetDesktopFileContentsForCommand(
     g_key_file_set_string(key_file, kDesktopEntry, "Icon",
                           GetIconName().c_str());
   }
-
-  g_key_file_set_string(key_file, kDesktopEntry, "X-Deepin-Vendor",
-                          "user-custom");
-
+                     
   // Set the "Categories" key.
   if (!categories.empty()) {
     g_key_file_set_string(
