@@ -8,6 +8,11 @@
 #include <utility>
 #include <vector>
 
+//添加debus
+#include "dbus/bus.h"
+#include "dbus/message.h"
+#include "dbus/object_proxy.h"
+
 #include "base/command_line.h"
 #include "base/metrics/histogram_functions.h"
 #include "base/metrics/histogram_macros.h"
@@ -118,6 +123,10 @@
 #include "url/gurl.h"
 #include "url/url_constants.h"
 
+#include "chrome/browser/themes/theme_service_factory.h"
+#include "chrome/browser/themes/theme_service.h"
+#include "ui/native_theme/native_theme.h"
+
 #if BUILDFLAG(ENABLE_EXTENSIONS)
 #include "chrome/browser/ui/extensions/app_launch_params.h"
 #include "chrome/browser/ui/extensions/application_launch.h"
@@ -148,6 +157,10 @@
 #include "chrome/browser/feature_engagement/incognito_window/incognito_window_tracker_factory.h"
 #endif
 
+#include "uos/dbus_thread_manager.h"
+#include "uos/dde/dde_appearance_theme_client.h"
+#include "uos/dde/dde_constants.h"
+
 namespace {
 
 const char kOsOverrideForTabletSite[] = "Linux; Android 9; Chrome tablet";
@@ -346,25 +359,21 @@ bool PrintPreviewShowing(const Browser* browser) {
 }  // namespace
 
 //add by xiepinze uos theme, 2020/07/24 start
-void UosThemeChange(Browser* browser, UosTheme theme) {
-  if (theme == UosTheme::UOS_THEME_LIGHT) {
-    //todo
-    LOG(ERROR) << "UosThemeChange UOS_THEME_LIGHT";
-  } else if (theme == UosTheme::UOS_THEME_DARK) {
-    //todo
-    LOG(ERROR) << "UosThemeChange UOS_THEME_DARK";
+//  浏览器应用自己更新了主题
+void UosThemeChange(int command) {
+  std::string sTheme = "";
+  if(command == IDC_UOS_LIGHT_THEME) {
+    sTheme = dbus::uos::kAppearanceGtkThemeLight;
+  } else if (command == IDC_UOS_DARK_THEME) {
+    sTheme = dbus::uos::kAppearanceGtkThemeDark;
   } else {
-    //todo
-    LOG(ERROR) << "UosThemeChange UOS_THEME_SYSTEM";
+    sTheme = dbus::uos::kAppearanceGtkThemeSystem;
   }
+  dbus::uos::DBusThreadManager::Get()->GetDdeAppearanceThemeClient()->setAppTheme(sTheme);
+  dbus::uos::DBusThreadManager::Get()->GetDdeAppearanceThemeClient()->updateAppThemeColor(sTheme);
 }
 //add by xiepinze uos theme, 2020/07/24 end
 
-//add by xiepinze help menu, 2020/07/29 start
-void CallUosHelp() {
-    LOG(ERROR) << "\n\nCallUosHelp\n\n";
-}
-//add by xiepinze help menu, 2020/07/29 end
 
 //add by xiepinze, add page zoom submenu, 2020/08/03, start
 void SetPageZoomLevel(const Browser* browser, const double zoom_level) {
@@ -1521,7 +1530,7 @@ bool CanViewSource(const Browser* browser) {
 void ShowBookmarkCurrentDlg(Browser* browser) {
   LOG(INFO)<<"ShowBookmarkCurrentDlg0";
   base::RecordAction(UserMetricsAction("StarDlg"));
-  size_t index;
+  size_t index = 0;
   BookmarkModel* model =
       BookmarkModelFactory::GetForBrowserContext(browser->profile());
   if (!model || !model->loaded())
