@@ -70,6 +70,8 @@
 #include "extensions/common/switches.h"
 #include "printing/buildflags/buildflags.h"
 
+#include "base/linux_util.h"
+
 #if defined(OS_CHROMEOS)
 #include "chrome/browser/chromeos/app_mode/app_launch_utils.h"
 #include "chrome/browser/chromeos/login/demo_mode/demo_app_launcher.h"
@@ -515,6 +517,9 @@ std::vector<GURL> StartupBrowserCreator::GetURLsFromCommandLine(
     Profile* profile) {
   DCHECK(profile);
 
+  LOG(INFO)<<"-------base::GetUosEdition-----"<<base::GetUosEdition();
+  // LOG(INFO)<<"-------base::GetUosEdition-----"<<base::GetUosEdition();
+
   std::vector<GURL> urls;
 
   const base::CommandLine::StringVector& params = command_line.GetArgs();
