@@ -944,22 +944,29 @@ bool BookmarkBarView::AreDropTypesRequired() {
 }
 
 bool BookmarkBarView::CanDrop(const ui::OSExchangeData& data) {
+  LOG(INFO)<<">>>>>CanDrop1:";
   if (!model_ || !model_->loaded() ||
       !browser_->profile()->GetPrefs()->GetBoolean(
           bookmarks::prefs::kEditBookmarksEnabled))
+  {
+    LOG(INFO)<<">>>>>CanDrop2:false";
     return false;
+  }
 
   if (!drop_info_.get())
     drop_info_ = std::make_unique<DropInfo>();
 
   // Only accept drops of 1 node, which is the case for all data dragged from
   // bookmark bar and menus.
+  bool value = (drop_info_->data.Read(data) && drop_info_->data.size() == 1);
+  LOG(INFO)<<">>>>>CanDrop3:"<<value;
   return drop_info_->data.Read(data) && drop_info_->data.size() == 1;
 }
 
 void BookmarkBarView::OnDragEntered(const ui::DropTargetEvent& event) {}
 
 int BookmarkBarView::OnDragUpdated(const ui::DropTargetEvent& event) {
+  LOG(INFO)<<">>>>>>>>OnDragUpdated";
   if (!drop_info_.get())
     return 0;
 
@@ -1014,6 +1021,7 @@ int BookmarkBarView::OnDragUpdated(const ui::DropTargetEvent& event) {
 }
 
 void BookmarkBarView::OnDragExited() {
+  LOG(INFO)<<">>>>>>OnDragExited";
   StopShowFolderDropMenuTimer();
 
   // NOTE: we don't hide the menu on exit as it's possible the user moved the
@@ -1029,6 +1037,7 @@ void BookmarkBarView::OnDragExited() {
 }
 
 int BookmarkBarView::OnPerformDrop(const ui::DropTargetEvent& event) {
+  LOG(INFO)<<">>>>>>>OnPerformDrop";
   StopShowFolderDropMenuTimer();
 
   if (bookmark_drop_menu_)
@@ -1158,7 +1167,7 @@ void BookmarkBarView::BookmarkNodeMoved(BookmarkModel* model,
                                         size_t old_index,
                                         const BookmarkNode* new_parent,
                                         size_t new_index) {
-              LOG(INFO)<<"BookmarkBarView::BookmarkNodeMoved";
+  LOG(INFO)<<"BookmarkBarView::BookmarkNodeMoved";
   bool was_throbbing =
       throbbing_view_ &&
       throbbing_view_ == DetermineViewToThrobFromRemove(old_parent, old_index);
@@ -1248,6 +1257,7 @@ void BookmarkBarView::BookmarkNodeFaviconChanged(BookmarkModel* model,
 void BookmarkBarView::WriteDragDataForView(View* sender,
                                            const gfx::Point& press_pt,
                                            ui::OSExchangeData* data) {
+  LOG(INFO)<<">>>>>WriteDragDataForView";
   base::RecordAction(base::UserMetricsAction("BookmarkBar_DragButton"));
 
   const auto* node = GetNodeForSender(sender);
@@ -1270,6 +1280,7 @@ void BookmarkBarView::WriteDragDataForView(View* sender,
 
 int BookmarkBarView::GetDragOperationsForView(View* sender,
                                               const gfx::Point& p) {
+  LOG(INFO)<<">>>>>GetDragOperationsForView";
   if (size_animation_.is_animating() ||
       size_animation_.GetCurrentValue() == 0) {
     // Don't let the user drag while animating open or we're closed. This
@@ -1285,6 +1296,8 @@ int BookmarkBarView::GetDragOperationsForView(View* sender,
 bool BookmarkBarView::CanStartDragForView(views::View* sender,
                                           const gfx::Point& press_pt,
                                           const gfx::Point& p) {
+  LOG(INFO)<<">>>>>CanStartDragForView";
+  
   // Check if we have not moved enough horizontally but we have moved downward
   // vertically - downward drag.
   gfx::Vector2d move_offset = p - press_pt;
@@ -1607,7 +1620,12 @@ void BookmarkBarView::ConfigureButton(const BookmarkNode* node,
     if (themify_icon && tp &&
         tp->HasCustomColor(ThemeProperties::COLOR_TOOLBAR_BUTTON_ICON)) {
       favicon = gfx::ImageSkiaOperations::CreateColorMask(
+          // modify by fangzhouyang, Use same color in both dark and light theme, 2021/3/18 --start
+          #if 0
           favicon, tp->GetColor(ThemeProperties::COLOR_TOOLBAR_BUTTON_ICON));
+          #endif
+          favicon, SkColorSetRGB(0x00, 0x81, 0xFF));
+          // modify by fangzhouyang, Use same color in both dark and light theme, 2021/3/18 --end
     }
 
     button->SetImage(views::Button::STATE_NORMAL, favicon);
