@@ -252,9 +252,9 @@ void BookmarkEditorView::Show(gfx::NativeWindow parent) {
     ExpandAndSelect();
   GetWidget()->Show();
   // Select all the text in the name Textfield.
-  //title_tf_->SelectAll(false);
+  title_tf_->SelectAll(true);
   // Give focus to the name Textfield.
-  //title_tf_->RequestFocus();
+  title_tf_->RequestFocus();
 }
 
 void BookmarkEditorView::ShowContextMenuForViewImpl(
@@ -484,7 +484,12 @@ GURL BookmarkEditorView::GetInputURL() const {
 void BookmarkEditorView::UserInputChanged() {
   if (details_.GetNodeType() != BookmarkNode::FOLDER) {
     const GURL url(GetInputURL());
+    // modify by xiaohuyang, fix bug 64486. 2021/3/8
+    // When the content of the address input box is invalid, the Alert frame is displayed, 
+    // which can prompt the user to pay attention to the address input box, but the tester thinks this is a bug.
+#if UNUSED
     url_tf_->SetInvalid(!url.is_valid());
+#endif
   }
   DialogModelChanged();
 }
