@@ -402,8 +402,13 @@ bool ExtensionInstallDialogView::Accept() {
 
 bool ExtensionInstallDialogView::IsDialogButtonEnabled(
     ui::DialogButton button) const {
+//wangfeng, del, (bug: 53479), 2020/12/28 --start
+//设置ok为默认按钮时，焦点设置失败问题
+#if UNUSE
   if (button == ui::DIALOG_BUTTON_OK)
     return install_button_enabled_;
+#endif
+//wangfeng, del, (bug: 53479), 2020/12/28 --end
   return true;
 }
 
