@@ -780,18 +780,7 @@ void LocationBarView::RefreshBackground() {
   if (omnibox_view_->model()->is_caret_visible()) {
     background_color = border_color = GetColor(OmniboxPart::RESULTS_BACKGROUND);
   } else {
-    // modify by xiaohuyang, Set the locationbar background color according to the window mode, 2020/09/02 --start
-#if 0
     const SkColor normal = GetColor(OmniboxPart::LOCATION_BAR_BACKGROUND);
-#else
-    SkColor normal;
-    if(browser_->profile()->IsIncognitoProfile()){
-      normal = gfx::kGoogleGrey900;
-    } else {
-      normal = SkColorSetRGB(0xEB, 0xEB, 0xEB);
-    }
-#endif
-    // modify by xiaohuyang, Set the locationbar background color according to the window mode, 2020/09/02 --end
     const SkColor hovered = GetOmniboxColor(
         GetThemeProvider(), OmniboxPart::LOCATION_BAR_BACKGROUND,
         OmniboxPartState::HOVERED);
